multidim.models.GaussianMixtureClassifier.score — GDA Toolbox v1.0 Manual

# multidim.models.GaussianMixtureClassifier.score

`GaussianMixtureClassifier.` `score`(pointclouds, labels)

  Score predicted labels against known labels.

  Parameters: | pointclouds : list-like A list of arrays. Each array is a pointcloud. Each row of that array is a point. labels : list-like A corresponding list of labels.
  Returns: | an array of booleans. True means the labels match.

  See also

  `score()`

#### Previous topic

multidim.models.GaussianMixtureClassifier.runit

#### Next topic

multidim.models.GaussianMixtureClassifier.set_params